@@ -1,4 +1,4 @@
-package MPMinus::Configuration; # $Id: Configuration.pm 128 2013-05-08 12:35:26Z minus $
+package MPMinus::Configuration; # $Id: Configuration.pm 135 2013-05-17 09:24:03Z minus $
 use strict;
 
 =head1 NAME
@@ -202,11 +202,11 @@ sub conf_init {
     #
     #     ( document_root)
     #
-    $conf{dir_conf}  = "conf";   #    
-    $conf{dir_logs}  = "/log";   #     document_root
-    $conf{dir_cache} = "/cache"; #    
-    $conf{dir_db}    = "/db";    #    
-    $conf{dir_shtml} = "/shtml"; #       ssi
+    $conf{dir_conf}  = "conf";  #    
+    $conf{dir_logs}  = "log";   #     document_root
+    $conf{dir_cache} = "cache"; #    
+    $conf{dir_db}    = "db";    #    
+    $conf{dir_shtml} = "shtml"; #       ssi
     
     #
     #        ( )
@@ -242,9 +242,10 @@ sub conf_init {
         and $conf{http_host}
         and $conf{http_host} !~ /\:\d+$/
        );
-    $conf{url}  = "http://".$conf{http_host}.$urlsfx;
-    $conf{urls} = "https://".$conf{http_host}.$urlsfx;
-    $conf{url_shtml} = "http://".$conf{http_host}.$urlsfx.$conf{dir_shtml};
+    $conf{url}        = "http://".$conf{http_host}.$urlsfx;
+    $conf{urls}       = "https://".$conf{http_host}.$urlsfx;
+    $conf{url_shtml}  = "http://".$conf{http_host}.$urlsfx.'/'.$conf{dir_shtml};
+    $conf{urls_shtml} = "https://".$conf{http_host}.$urlsfx.'/'.$conf{dir_shtml};
 
     #
     #  (     _ )
